pub struct FastQCConfig {Show 20 fields
pub nogroup: bool,
pub expgroup: bool,
pub quiet: bool,
pub kmer_size: u8,
pub threads: usize,
pub output_dir: Option<PathBuf>,
pub casava: bool,
pub nano: bool,
pub nofilter: bool,
pub do_unzip: Option<bool>,
pub delete_after_unzip: bool,
pub sequence_format: Option<String>,
pub contaminant_file: Option<PathBuf>,
pub adapter_file: Option<PathBuf>,
pub limits_file: Option<PathBuf>,
pub min_length: usize,
pub dup_length: usize,
pub svg_output: bool,
pub temp_dir: Option<PathBuf>,
pub template: TemplateName,
}Expand description
Configuration for a FastQC run, mirroring all fields from Java FastQCConfig.
Fields
nogroup: boolexpgroup: boolquiet: boolkmer_size: u8threads: usizeoutput_dir: Option<PathBuf>casava: boolnano: boolnofilter: booldo_unzip: Option<bool>delete_after_unzip: boolsequence_format: Option<String>contaminant_file: Option<PathBuf>adapter_file: Option<PathBuf>limits_file: Option<PathBuf>min_length: usizedup_length: usizesvg_output: booltemp_dir: Option<PathBuf>template: TemplateNameImplementations
Sourceimpl FastQCConfig
impl FastQCConfig
Sourcepub fn load_limits(&self) -> Result<Limits>
pub fn load_limits(&self) -> Result<Limits>
Load module limits from the configured file or the embedded default.
Parsing matches ModuleConfig.java - lines starting with ‘#’
are comments, blank lines are skipped, and each data line has whitespace-
separated fields: module level value.
Sourcepub fn load_adapters(&self) -> Result<Vec<(String, String)>>
pub fn load_adapters(&self) -> Result<Vec<(String, String)>>
Load adapter sequences from the configured file or the embedded default.
Returns a list of (name, sequence) pairs.
Parsing matches the Java adapter loading - lines starting with ‘#’ are comments, blank lines are skipped, and each data line is tab- delimited with name and sequence columns.